use std::collections::HashMap;

use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, Debug)]
pub struct Plan {
    plan: Vec<PlanElement>,
    current: usize,
    stored_path: Option<String>,
}
impl Plan {
    pub fn set_stored_path(&mut self, file: String) {
        self.stored_path = Some(file);
    }
}

#[derive(Debug, Deserialize, Serialize)]
pub struct PlanElement {
    area_key: String,
    notes: String,
}

#[derive(Debug, Deserialize)]
struct OldPlanElement {
    area: OldArea,
    note: String,
}

#[derive(Debug, Deserialize)]
struct OldPlan {
    elements: Vec<OldPlanElement>,
    position: usize,
}

#[derive(Debug, Deserialize)]
struct OldArea {
    _rid: usize,
}

pub fn convert_old(path: &str) -> Option<Plan> {
    let plan: OldPlan =
        serde_json::from_str(&std::fs::read_to_string(path).expect("Could not convert old"))
            .expect("could not convert old");

    let map = poe_data::world_area::load_world_areas_map(include_str!(
        "../../data/processed_world_areas.json"
    ));
    let map = map
        .iter()
        .map(|(k, v)| (v.key_id, k))
        .collect::<HashMap<usize, &String>>();

    Some(Plan {
        current: plan.position,
        plan: plan
            .elements
            .into_iter()
            .map(|plan_element| PlanElement {
                area_key: map[&plan_element.area._rid].to_owned(),
                notes: plan_element.note,
            })
            .collect::<Vec<PlanElement>>(),
            stored_path: None
    })
}
